@@ -30,7 +30,7 @@ def register(excelFile: "Excel file containing the component data",
         logger.info("Modified the dataframe")
         assert isinstance(df, pd.DataFrame)
         print(df)
-
+    # Loop over the rows
     for i, r in df.iterrows():
         JSON = {}
         JSON['institution'] = institution
@@ -40,15 +40,22 @@ def register(excelFile: "Excel file containing the component data",
         JSON['type'] = subType
 
         Properties = {}
+        Batches = {}
+        # Loop over the columns in the row
         for i, k in enumerate(r.keys()):
             if k == "serialNumber":
                 JSON["serialNumber"] = r[k]
             elif k == "alternativeIdentifier":
                 JSON["alternativeIdentifier"] = r[k]
                 JSON["serialNumber"] = None
+            elif k.startswith("B_"):
+                k = k[2:]
+                Batches[k] = r[k]
             else:
                 Properties[k] = r[k]
         JSON['properties'] = Properties
+        if Batches != {}:
+            JSON["batches"] = Batches
         dd.register(JSON)
 
 
