@@ -350,12 +350,33 @@ def assemble(parent:     "Parent component identifier (ATLAS SN or alternative I
             f"Unable to assemble component in the DB, is the format correct?")
 
 
+def property(componentID: "Component identifier or ATLAS serial number",
+             property: "Property code",
+             value: "Target value "):
+    "Change a component property"
+    try:
+        client = itkdb.Client()
+        data = {
+            'component': componentID,
+            'code': property,
+            'value': value
+        }
+
+        client.post('setComponentProperty', data=data)
+        logger.info(f"Changed property {property} of {componentID} to {value}")
+    except Exception as e:
+        logger.error(e)
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
                         attach, tests, stage,
                         skeleton, upload, testruns,
-                        testfile, assemble])
+                        testfile, assemble, property])
     parser.dispatch()
 
 
